@@ -4,8 +4,8 @@
 
 ;; Author: Alvaro Ramirez https://xenodium.com
 ;; URL: https://github.com/xenodium/shell-maker
-;; Package-Version: 20260213.1201
-;; Package-Revision: a7ff78f8cd29
+;; Package-Version: 20260302.1711
+;; Package-Revision: 238b1e4f0078
 ;; Package-Requires: ((emacs "27.1"))
 
 ;; This package is free software; you can redistribute it and/or modify
@@ -33,7 +33,7 @@
 
 ;;; Code:
 
-(defconst shell-maker-version "0.85.2")
+(defconst shell-maker-version "0.86.1")
 
 (require 'comint)
 (require 'goto-addr)
@@ -1347,7 +1347,9 @@ Use ON-OUTPUT function to monitor output text."
                               :on-output on-output
                               :failed (not success))
     (when auto-scroll
-      (goto-char (point-max)))))
+      (goto-char (point-max))))
+  (when success
+    (shell-maker--write-input-ring-history config)))
 
 (defmacro shell-maker-with-auto-scroll-edit (&rest body)
   "Execute BODY, preserving point unless already at end of buffer."
